# Generated by Django 2.0.5 on 2019-02-12 10:53

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('sidekick', '0002_create_common_cron'),
    ]

    operations = [
        migrations.AlterField(
            model_name='task',
            name='cron_schedule',
            field=models.ForeignKey(null=True, blank=True, on_delete=django.db.models.deletion.DO_NOTHING, to='sidekick.CronSchedule'),
        ),
        migrations.AlterField(
            model_name='task',
            name='registered_task',
            field=models.ForeignKey(null=True, blank=True, on_delete=django.db.models.deletion.CASCADE, to='sidekick.RegisteredTask'),
        ),
    ]
